@@ -1,5 +1,5 @@
+import math
 from pyglet.gl import glClearColor
-import random
 from typing import Optional
 from ververser import GameWindow
 
@@ -8,11 +8,12 @@ class Game:
 
     def __init__( self, game_window : GameWindow ):
         self.game_window = game_window
+        self.total_time = 0
 
     def update( self, dt ):
-        random_range = 0.1
-        green = 0.5 + (( random_range * random.uniform(0, 1) ) - 0.5 * random_range )
-        glClearColor( 0, green, 0, 1.0 )
+        self.total_time += dt
+        g = 0.25 + 0.25 * ( math.sin( self.total_time ) + 1 )
+        glClearColor( 0, g, 0, 1.0 )
 
     def draw( self ):
         ...
@@ -23,12 +24,12 @@ class Game:
 
 _GAME : Optional[ Game ] = None
 
-def init( game_window : GameWindow ):
+def vvs_init( game_window : GameWindow ):
     global _GAME
     _GAME = Game( game_window )
 
-def update( dt ):
+def vvs_update( dt ):
     _GAME.update( dt )
 
-def draw():
+def vvs_draw():
     _GAME.draw()
\ No newline at end of file
